//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI;

import javax.swing.*;
import java.awt.*;
import ch.hearc.I04_05s08.GUI.Graph.*;

/**
 *	Dialog box
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public abstract class DialogBox extends SimpleDialog
{
	/**
	 *	The node
	 */
	private Element element;
	
	/**
	 *	The graph
	 */
	private GraphPanel graph;

	/**
	 *	Build a new dialog box
	 *
	 *	@param	title		The title of the dialog box
	 *	@param	element		The graphic element
	 */
	public DialogBox(String title, Element element, GraphPanel graph)
	{
		super(title);
		
		this.element = element;
		this.graph = graph;
	}
	
	/**
	 *	Center the dialog on the screen
	 */
	public void centerScreen()
	{
		Dimension dim = getToolkit().getScreenSize();
		Rectangle abounds = getBounds();
		setLocation(
			(dim.width - abounds.width) / 2,
			(dim.height - abounds.height) / 2
		);
	}
	
	/**
	 *	Get the graph
	 *
	 *	@return the graph
	 */
	public GraphPanel getGraph()
	{
		return graph;
	}
	
	/**
	 *	Get the element
	 *
	 *	@return element
	 */
	public Element getElement()
	{
		return element;
	}
	
	/**
	 *	Clear the values
	 */
	public abstract void clear();
}
