//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI;

import java.awt.event.*;
import javax.swing.*;

/**
 *	The menu of the system
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public class MenuApplication extends JMenuBar
{
	/**
	 *	Title of the elements of the menu
	 */
	private String[] roots;
		
	/**
	 *	Key of the menu's element
	 */
	private int[] rootKeys;
	
	/**
	 *	The JMenu
	 */
	private JMenu[] rootMenus;
	
	// RDFS
	
	/**
	 *	RDFS submenu
	 */
	private JMenu rdfsMenu;
	
	/**
	 *	RDFS submenu's title
	 */
	private String rdfsMenuTitle;
		
	/**
	 *	RDFS items
	 */
	private JMenuItem[] rdfsItems;
	
	/**
	 *	RDFS items' title
	 */
	private String[] rdfsItemsTitle;
	
	// RDF
	
	/**
	 *	RDF submenu
	 */
	private JMenu rdfMenu;
	
	/**
	 *	RDF submenu's title
	 */
	private String rdfMenuTitle;
	
	/**
	 *	RDF items
	 */
	private JMenuItem[] rdfItems;
	
	/**
	 *	RDF items' title
	 */
	private String[] rdfItemsTitle;
	
	// File
	
	/**
	 * File items
	 */
	private JMenuItem[] fileItems;
	
	/**
	 *	File item's title
	 */
	private String[] fileItemsTitle;
	
	/**
	 *	File item's shortcuts
	 */
	private KeyStroke[] fileItemsKeys;
	
	// Edit
	
	/**
	 *	Edit menu items
	 */
	private JMenuItem[] editItems;
	
	/**
	 *	Edit menu items' title
	 */
	private String[] editItemsTitle;
	
	/**
	 *	Edit menu items' shortcuts
	 */
	private KeyStroke[] editItemsKeys;
	
	// Help
	
	/**
	 *	Help menu items
	 */
	private JMenuItem[] helpItems;
	
	/**
	 *	Help menu items' title
	 */
	private String[] helpItemsTitle;
	
	/**
	 *	Help menu items' shortcuts
	 */
	private KeyStroke[] helpItemsKeys;
	
	//--
	
	/**
	 *	Build the menu
	 */
	public MenuApplication()
	{
		super();
		
		// root
		roots = new String[]{
			"File",
			"Edit",
			"Help"
		};
		
		rootKeys = new int[]{
			KeyEvent.VK_F,
			KeyEvent.VK_E,
			KeyEvent.VK_H
		};
		
		// rdfs
		rdfsMenuTitle = "RDF Schema";
		
		rdfsItemsTitle = new String[]{
			"New File",
			"Open File"
		};
		
		// rdf
		rdfMenuTitle = "RDF";
		
		rdfItemsTitle = new String[]{
			"New File",
			"Open File",
			null,
			"New File with RDF Schema(s)",
			"Open File with RDF Schema(s)"
		};
		
		// file
		fileItemsTitle = new String[]
		{
			null,
			"Save",
			"Save as",
			null,
			"Close",
			"Exit"
		};
		
		fileItemsKeys = new KeyStroke[]{
			null,
			KeyStroke.getKeyStroke(KeyEvent.VK_S, KeyEvent.CTRL_MASK),
			KeyStroke.getKeyStroke(KeyEvent.VK_S, KeyEvent.CTRL_MASK ^ KeyEvent.SHIFT_MASK),
			null,
			KeyStroke.getKeyStroke(KeyEvent.VK_W, KeyEvent.CTRL_MASK),
			KeyStroke.getKeyStroke(KeyEvent.VK_F4, KeyEvent.ALT_MASK)
		};
		
		
		// edit
		editItemsTitle = new String[]{
			"Cut",
			"Copy",
			"Delete"
		};
		
		editItemsKeys = new KeyStroke[]{
			KeyStroke.getKeyStroke(KeyEvent.VK_X, KeyEvent.CTRL_MASK),
			KeyStroke.getKeyStroke(KeyEvent.VK_C, KeyEvent.CTRL_MASK),
			KeyStroke.getKeyStroke(KeyEvent.VK_DELETE, 0)
		};
		
		// help
		helpItemsTitle = new String[]{
			"Help",
			"About"
		};
		
		helpItemsKeys = new KeyStroke[]{
			KeyStroke.getKeyStroke(KeyEvent.VK_F1, 0),
			null
		};
		
		buildMenu();
	}
	
	/**
	 *	Create the JMenu elements
	 */
	private void buildMenu()
	{		
		// root
		rootMenus = new JMenu[roots.length];
		
		for(int i=0; i<roots.length; i++)
		{
			rootMenus[i] = new JMenu(roots[i]);
			rootMenus[i].setMnemonic(rootKeys[i]);
			add(rootMenus[i]);
		}
		
		// rdfs
		rdfsMenu = new JMenu(rdfsMenuTitle);
		
		rdfsItems = new JMenuItem[rdfsItemsTitle.length];
		
		for(int i=0; i<rdfsItems.length; i++)
		{
			if(rdfsItemsTitle[i] != null)
			{
				rdfsItems[i] = new JMenuItem(rdfsItemsTitle[i]);
				rdfsMenu.add(rdfsItems[i]);
			}
			else
			{
				rdfsMenu.addSeparator();
			}
		}
		
		// rdf

		rdfMenu = new JMenu(rdfMenuTitle);
		
		rdfItems = new JMenuItem[rdfItemsTitle.length];
		
		for(int i=0; i<rdfItems.length; i++)
		{
			if(rdfItemsTitle[i] != null)
			{
				rdfItems[i] = new JMenuItem(rdfItemsTitle[i]);
				rdfMenu.add(rdfItems[i]);
			}
			else
			{
				rdfMenu.addSeparator();
			}
		}
		
		// File
		fileItems = new JMenuItem[fileItemsTitle.length];
		
		rootMenus[0].add(rdfsMenu);
		rootMenus[0].add(rdfMenu);
		
		for(int i=0; i<fileItems.length; i++)
		{
			if(fileItemsTitle[i] != null)
			{
				fileItems[i] = new JMenuItem(fileItemsTitle[i]);
				fileItems[i].setAccelerator(fileItemsKeys[i]);
				rootMenus[0].add(fileItems[i]);
			}
			else
			{
				rootMenus[0].addSeparator();
			}
		}
		
		// Edit
		editItems = new JMenuItem[editItemsTitle.length];
		
		for(int i=0; i<editItems.length; i++)
		{
			editItems[i] = new JMenuItem(editItemsTitle[i]);
			editItems[i].setAccelerator(editItemsKeys[i]);
			rootMenus[1].add(editItems[i]);
		}
		
		// Help
		helpItems = new JMenuItem[helpItemsTitle.length];
		
		for(int i=0; i<helpItems.length; i++)
		{
			helpItems[i] = new JMenuItem(helpItemsTitle[i]);
			helpItems[i].setAccelerator(helpItemsKeys[i]);
			rootMenus[2].add(helpItems[i]);
		}
	}
	
	//--
	
	/**
	 *	Get file items
	 *
	 *	@return file buttons
	 */
	public JMenuItem[] getFileItems()
	{
		return fileItems;
	}
	
	/**
	 *	Get MenuItem for the help
	 *
	 *	@return help button
	 */
	public JMenuItem getHelpItem()
	{
		return helpItems[0];
	}
	
	/**
	 *	Get MenuItem for about text
	 *
	 *	@return about button
	 */
	public JMenuItem getAboutItem()
	{
		return helpItems[1];
	}
	
	//--
	
	/**
	 *	Get MenuItem for cutting
	 *
	 *	@return cut button
	 */
	public JMenuItem getCutItem()
	{
		return editItems[0];
	}
	
	/**
	 *	Get MenuItem for copying
	 *
	 *	@return copy button
	 */
	public JMenuItem getCopyItem()
	{
		return editItems[1];
	}
	
	/*
	 *	Get MenuItem for pasting
	 *
	 *	@return paste button
	 /
	public JMenuItem getPasteItem()
	{
		return editItems[2];
	}*/
	
	/**
	 *	Get MenuItem for deleting
	 *
	 *	@return delete button
	 */
	public JMenuItem getDeleteItem()
	{
		return editItems[2];
	}
	
	//-
	
	/**
	 *	Get RDF Schema items
	 *
	 *	<ol>
	 *		<li>New File</li>
	 *		<li>Open File</li>
	 *	</ol>
	 *
	 *	@return items of the RDF Schema submenu
	 */
	public JMenuItem[] getRdfsItems()
	{
		return rdfsItems;
	}
	
	/**
	 *	Get RDF items
	 *
	 *	<ol>
	 *		<li>New File</li>
	 *		<li>Open File</li>
	 *		<li><code>null</code></li>
	 *		<li>New File with RDF Schema(s)</li>
	 *		<li>Open File with RDF Schema(s)</li>
	 *	</ol>
	 *
	 *	@return items of the RDF submenu
	 */
	public JMenuItem[] getRdfItems()
	{
		return rdfItems;
	}
}
