//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI.RDF;

import ch.hearc.I04_05s08.GUI.*;
import ch.hearc.I04_05s08.GUI.Graph.*;
import ch.hearc.I04_05s08.Ontology.*;
import ch.hearc.I04_05s08.Ontology.RDF.*;
import ch.hearc.I04_05s08.Ontology.RDFS.*;
import javax.swing.*;

/**
 *	A manager for RDF graphs
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public class RdfGraphManager implements GraphManager
{	
	/**
	 *	Frame
	 */
	private MainApplication mainframe;
	
	/**
	 *	File chooser
	 */
	private JFileChooser jfc;
	
	//--
	
	/**
	 *	Build the graph manager
	 *
	 *	@param mainframe		the parent frame
	 */
	public RdfGraphManager(MainApplication mainframe)
	{
		this.mainframe = mainframe;
		
		jfc = new JFileChooser();
		
		SimpleFileFilter filter = new SimpleFileFilter();
		filter.addExtension("rdf");
		filter.addExtension("xml");
		filter.setDescription("RDF File");
		jfc.setFileFilter(filter);
	}
	
	/**
	 *	Build a new graph
	 */
	public void newGraph()
	{
		loadGraph(new RdfFile(""));
	}
	
	/**
	 *	Build a new graph with rdfs
	 */
	public void newGraphRdf()
	{
		new RdfNewFileDialog(this);
	}
	
	/**
	 *	Open a graph with this file
	 *
	 *	@return 				if the operation successed
	 */
	public boolean openGraph()
	{
		String file = choose();
		if(file != null)
			return loadGraph(OntManager.openRdf(file));
		else
			return false;
	}
	
	/**
	 *	Open a graph with rdfs
	 */
	public boolean openGraphRdf()
	{
		new RdfOpenFileDialog(this);
		return true;
	}
	
	/**
	 *	Choose a file
	 */
	public String choose()
	{
		int returnVal = jfc.showOpenDialog(mainframe);
		
		if(returnVal == JFileChooser.APPROVE_OPTION)
		{
			return jfc.getSelectedFile().getPath();
		}
		else
		{
			return null;
		}
	}
	
	/**
	 *	Save the graph into a file
	 *
	 *	@return				if the operation successed
	 */
	public boolean saveGraph()
	{
		if(mainframe.getCurrentTab().getFile().getName().equals(""))
		{
			mainframe.getCurrentTab().setFilename(choose());
			mainframe.updateCurrentTab();
		}
		
		return OntManager.saveRdf(
			mainframe.getCurrentTab().getFile().getFilename(),
			(RdfFile)mainframe.getCurrentTab().getFile()
		);
	}
	
	/**
	 *	Save the graph into another file
	 *
	 *	@return if the operation successed
	 */
	public boolean saveAsGraph()
	{
		mainframe.getCurrentTab().setFilename("");
		
		return saveGraph();
	}
	
	/**
	 *	Save the graph into another file
	 *
	 *	@return if the operation successed
	 */
	public boolean closeGraph()
	{
		Object[] options = {
			"Save and close",
			"Close without saving",
			"Cancel"
		};
		
		int n = JOptionPane.showOptionDialog(
			mainframe,
			"Closing the graph ?",
			"Close " + mainframe.getCurrentTab().getTitle(),
			JOptionPane.YES_NO_CANCEL_OPTION,
			JOptionPane.WARNING_MESSAGE,
			null,
			options,
			options[0]
		);
		
		if(n == JOptionPane.YES_OPTION)
		{
			if(!saveGraph())
				//return false;
			
			mainframe.removeTab();
		}
		else if(n == JOptionPane.NO_OPTION)
		{
			mainframe.removeTab();
		}
		else
		{
			return false;
		}
		
		return true;	
	}
	
	/**
	 *	Load the graph
	 *
	 *	@param file		the RDF file
	 *	@return il operation successed	
	 */
	public boolean loadGraph(RdfFile file)
	{
		if(file != null)
		{
			mainframe.addTab(new RdfTab(file, mainframe));
			return true;
		}
		else
		{
			return false;
		}
	}
	
	/**
	 *	Get the main frame
	 *
	 *	@return the main frame
	 */
	public MainApplication getMainFrame()
	{
		return mainframe;
	}
}
