//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI.RDFS;

import ch.hearc.I04_05s08.GUI.Graph.*;
import ch.hearc.I04_05s08.Ontology.RDFS.RdfsResource;

/**
 *	A node for RDFS graph
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public abstract class RdfsNode extends Node
{
	/**
	 *	RFDS Resource
	 */
	private RdfsResource resource;
	
	/**
	 *	RdfsGraph
	 */
	private GraphPanel graph;
	
	/**
	 *	Build a rdfs node
	 *
	 *	@param res		the RDFS Resource
	 */
	public RdfsNode(RdfsResource res)
	{
		super((res.getLabel() == null ? res.getShortName() : res.getLabel()));
		
		this.resource = res;
	}

	/**
	 *	Get the RDFS Resource
	 *
	 *	@return RDFS Resource
	 */
	public RdfsResource getResource()
	{
		return resource;
	}
	
	/**
	 *	Set the url of the resource
	 *
	 *	@param url	resource's url
	 */
	public void setName(String url)
	{
		resource.setName(url);
	}
	
	/**
	 *	Set the label of the resource
	 *
	 *	@param label	resource's title
	 */
	public void setLabel(String label)
	{
		resource.setLabel(label);
	}
	
	/**
	 *	Set the comment of the resource
	 *
	 *	@param comment	resource's label
	 */
	public void setComment(String comment)
	{
		resource.setComment(comment);
	}
	
	/**
	 *	Display a dialog box for this node
	 *
	 *	@param graph		the graph
	 */
	public void showDialog(GraphPanel graph)
	{
		if(graph instanceof RdfsGraph)
		{
			this.graph = graph;
			new RdfsDialog(this,(RdfsGraph)graph);
		}
	}
	
	/**
	 *	Update the node
	 */
	public void update()
	{
		super.update();
		setTitle((resource.getLabel() == null ? resource.getShortName() : resource.getLabel()));
		
		if(graph != null)
		{
			graph.invalidate();
			graph.repaint();
		}
	}
}
