//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI.RDFS;

import javax.swing.*;
import ch.hearc.I04_05s08.GUI.RDFS.*;
import ch.hearc.I04_05s08.GUI.Graph.*;

/**
 *	Button for the RDFS toolbar
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public class RdfsToolButton extends JButton
{	
	/**
	 *	The mode for the graph
	 */
	private int mode;
	
	/**
	 *	The element to draw
	 */
	private Element e;
	
	/**
	 *	Build the RDFS toolbar button
	 *
	 *	@param title		the label of the button
	 *	@param i			the icon
	 *	@param mode			the drawing mode
	 *	@param e			the element
	 */
	public RdfsToolButton(String title, Icon i, int mode, Element e)
	{
		super(title, i);
		
		this.e = e;
		this.mode = mode;
	}
	
	/**
	 *	Build the RDFS toolbar button
	 *
	 *	@param title		the label of the button
	 *	@param mode			the drawing mode
	 *	@param e			the element
	 */
	public RdfsToolButton(String title, int mode, Element e)
	{
		this(title, null, mode, e);
	}
	
	/**
	 *	Get the graph mode
	 *
	 *	@return the mode
	 */
	public int getMode()
	{
		return mode;
	}
	
	/**
	 *	Get a clone of the element
	 *
	 *	@return a clone of the element
	 */
	public Element getElement()
	{
		return (Element)e.clone();
	}
}
