//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.GUI;

import ch.hearc.I04_05s08.Ontology.OntFile;
import ch.hearc.I04_05s08.Ontology.RDFS.*;
import ch.hearc.I04_05s08.GUI.Graph.GraphPanel;
import javax.swing.*;
import java.awt.*;

/**
 *	A tab
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */

public abstract class Tab extends JPanel
{	
	/**
	 *	The graph
	 */
	private GraphPanel graph;
	
	/**
	 *	The manager
	 */
	private GraphManager manager;
	
	/**
	 *	The filename
	 */
	private String filename;
	
	/**
	 *	The file
	 */
	private OntFile file;
	
	/**
	 *	A new Tab
	 */
	public Tab(OntFile file, GraphManager manager)
	{
		this.file = file;
		this.manager = manager;
		
		setLayout(new BorderLayout());
	}
	
	/**
	 *	Init the graph (called by setGraph)
	 */
	public abstract void init();
	
	/**
	 *	Set the graph
	 *
	 *	@param graph		the graph
	 */
	public void setGraph(GraphPanel graph)
	{
		this.graph = graph;
		init();
	}
	
	/**
	 *	Get the graph
	 *
	 *	@return the graph
	 */
	public GraphPanel getGraph()
	{
		return graph;
	}
	
	/**
	 *	Get the manager
	 *
	 *	@return the manager
	 */
	public GraphManager getManager()
	{
		return manager;
	}
	
	/**
	 *	Get title
	 *
	 *	@return the file's title
	 */
	public String getTitle()
	{
		return (!isFile() ? "Untitled" : file.getName());
	}
	
	/**
	 *	Get if the file is already saved (not an untitled file)
	 *
	 *	@return if the file isn't untitled
	 */
	public boolean isFile()
	{
		return (!file.getName().equals(""));
	}
	
	/**
	 *	Get the file
	 *
	 *	@return the file
	 */
	public OntFile getFile()
	{
		return file;
	}
	
	/**
	 *	Set the file's name
	 *
	 *	@param filename		the new path of the file
	 */
	public void setFilename(String filename)
	{
		file.setFilename(filename);
	}
}
