//
// Copyright (c) 2005 Yoan Blanc, HE-ARC Ingnierie (Le Locle)
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy of
// this software and associated documentation files (the "Software"), to deal in
// the Software without restriction, including without limitation the rights to use,
// copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the
// Software, and to permit persons to whom the Software is furnished to do so,
// subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
// OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER
// IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

package ch.hearc.I04_05s08.Ontology;

import java.io.File;
import java.io.FileInputStream;
import java.io.InputStreamReader;
import java.io.IOException;

/**
 *	An base class for any files in Ontology
 *
 *	@author Blanc, Yoan
 *	@hearc.copyright 2005 Yoan Blanc, HE-ARC Ingnierie
 *	@hearc.licence <a href="http://opensource.org/licenses/mit-license.php">MIT</a>
 */
 
public class OntFile
{
	/**
	 *	The path of the file
	 */
	private String filename;
	
	/**
	 *	The file's input stream
	 */
	private FileInputStream inFile;
	
	/**
	 *	The file
	 */
	private File file;
	
	// Constructors ///////////////////////////////////////////////////////////

	/**
	 *	Construct the file
	 *
	 *	@param filename		the path of the file
	 */
	public OntFile(String filename)
	{
		this.filename = filename;
	}
	
	/**
	 *	Construct an untitled file
	 *
	 *	@version 0.1.3
	 */
	public OntFile ()
	{
		this.filename = "";
	}
	
	// Public /////////////////////////////////////////////////////////////////
	
	/**
	 *	String representation of the file
	 *
	 *	@return file's name (given by the user)
	 */
	public String toString()
	{
		return filename;
	}
	
	/**
	 *	File's name
	 *
	 *	@return	the file's name (real)
	 */
	public String getName()
	{
		return (file != null
			? file.getName()
			: filename);
	}
	
	/**
	 *	Return a reader for the file
	 *
	 *	@return a stream reader
	 */
	public FileInputStream getReader()
	{
		if(inFile == null)
		{
			initReader();
		}
		return inFile;
	}
	
	/**
	 *	Close the file
	 */
	public void close()
	{
		if(inFile != null)
		{
			try
			{
				inFile.close();
			}
			catch(IOException e)
			{
				System.out.println("OntFile : " + e);
				e.printStackTrace();
			}
			
			inFile = null;
		}
	}
	
	/**
	 *	Set the path of the file
	 *
	 *	@param filename		the file's path
	 */
	public void setFilename(String filename)
	{
		this.filename = filename;
		file = new File(filename);
	}
	
	/**
	 *	Return the path of the file
	 *
	 *	@return the file's path
	 */
	public String getFilename()
	{
		return filename;
	}
	
	/**
	 *	Build the file's reader
	 *
	 *	@return the operation's success
	 */
	private boolean initReader()
	{
		try
		{
			file = new File(filename);
			inFile = new FileInputStream(file);
			
			return true;
		}
		catch(IOException e)
		{
			System.out.println("OntFile : " + e);
			e.printStackTrace();
			
			return false;
		}
	}
}
